@@ -1,5 +1,6 @@
 /***************************************************************************
-* Copyright (c) 2016, Wolf Vollprecht, Sylvain Corlay and Johan Mabille    *
+* Copyright (c) Wolf Vollprecht, Sylvain Corlay and Johan Mabille          *
+* Copyright (c) QuantStack                                                 *
 *                                                                          *
 * Distributed under the terms of the BSD 3-Clause License.                 *
 *                                                                          *
@@ -111,7 +112,13 @@ namespace xt
             }
             else
             {
-                zstr::istream zstream(stream, compr_bytes);
+                if (compr_bytes == 0xffffffff)
+                {
+                    throw std::runtime_error("load_npz: ZIP64 is not implemented");
+                }
+
+                auto pos = stream.tellg();
+                zstr::istream zstream(stream);
 
                 if (!zstream)
                 {
@@ -120,6 +127,7 @@ namespace xt
 
                 arrays.insert(result_type::value_type(varname,
                                                       detail::load_npy_file(zstream)));
+                stream.seekg(pos + std::streamoff(compr_bytes));
             }
         }
         return arrays;
@@ -199,7 +207,13 @@ namespace xt
                 }
                 else
                 {
-                    zstr::istream zstream(stream, compr_bytes);
+                    if (compr_bytes == 0xffffffff)
+                    {
+                        throw std::runtime_error("load_npz: ZIP64 is not implemented");
+                    }
+
+                    auto pos = stream.tellg();
+                    zstr::istream zstream(stream);
 
                     if (!zstream)
                     {
@@ -207,6 +221,7 @@ namespace xt
                     }
 
                     detail::npy_file f = detail::load_npy_file(zstream);
+                    stream.seekg(pos + std::streamoff(compr_bytes));
                     return f.cast<T>();
                 }
             }
